==> vplus-0.2.0-sources.jar: tech/nevets/vplus/blocks/ColorWallTorchBlock.java <==
package tech.nevets.vplus.blocks;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2527;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2753;
import net.minecraft.class_2769;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import org.jetbrains.annotations.Nullable;

import java.util.Map;
import java.util.Random;

public class ColorWallTorchBlock extends class_2527 {
    public static final class_2753 FACING;
    protected static final float field_31285 = 2.5F;
    private static final Map<class_2350, class_265> BOUNDING_SHAPES;

    protected ColorWallTorchBlock(class_2251 settings, class_2394 ) {
        super(settings, );
        this.method_9590((class_2680)((class_2680)this.field_10647.method_11664()).method_11657(FACING, class_2350.field_11043));
    }

    public String method_9539() {
        return this.method_8389().method_7876();
    }

    public class_265 method_9530(class_2680 state, class_1922 , class_2338 , class_3726 ) {
        return getBoundingShape(state);
    }

    public static class_265 getBoundingShape(class_2680 state) {
        return (class_265)BOUNDING_SHAPES.get(state.method_11654(FACING));
    }

    public boolean method_9558(class_2680 state, class_4538 , class_2338 ) {
        class_2350 direction = (class_2350)state.method_11654(FACING);
        class_2338 blockPos = .method_10093(direction.method_10153());
        class_2680 blockState = .method_8320(blockPos);
        return blockState.method_26206(, blockPos, direction);
    }

    @Nullable
    public class_2680 method_9605(class_1750 ctx) {
        class_2680 blockState = this.method_9564();
        class_4538 worldView = ctx.method_8045();
        class_2338 blockPos = ctx.method_8037();
        class_2350[] directions = ctx.method_7718();
        class_2350[] var6 = directions;
        int var7 = directions.length;

        for(int var8 = 0; var8 < var7; ++var8) {
            class_2350 direction = var6[var8];
            if (direction.method_10166().method_10179()) {
                class_2350 direction2 = direction.method_10153();
                blockState = (class_2680)blockState.method_11657(FACING, direction2);
                if (blockState.method_26184(worldView, blockPos)) {
                    return blockState;
                }
            }
        }

        return null;
    }

    public class_2680 method_9559(class_2680 state, class_2350 , class_2680 , class_1936 , class_2338 , class_2338 ) {
        return .method_10153() == state.method_11654(FACING) && !state.method_26184(, ) ? class_2246.field_10124.method_9564() : state;
    }

    public void method_9496(class_2680 state, class_1937 , class_2338 , Random ) {
        class_2350 direction = (class_2350)state.method_11654(FACING);
        double d = (double).method_10263() + 0.5D;
        double e = (double).method_10264() + 0.7D;
        double f = (double).method_10260() + 0.5D;
        double g = 0.22D;
        double h = 0.27D;
        class_2350 direction2 = direction.method_10153();
        .method_8406(class_2398.field_11251, d + 0.27D * (double)direction2.method_10148(), e + 0.22D, f + 0.27D * (double)direction2.method_10165(), 0.0D, 0.0D, 0.0D);
        .method_8406(this.field_22155, d + 0.27D * (double)direction2.method_10148(), e + 0.22D, f + 0.27D * (double)direction2.method_10165(), 0.0D, 0.0D, 0.0D);
    }

    public class_2680 method_9598(class_2680 state, class_2470 ) {
        return (class_2680)state.method_11657(FACING, .method_10503((class_2350)state.method_11654(FACING)));
    }

    public class_2680 method_9569(class_2680 state, class_2415 ) {
        return state.method_26186(.method_10345((class_2350)state.method_11654(FACING)));
    }

    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(new class_2769[]{FACING});
    }

    static {
        FACING = class_2383.field_11177;
        BOUNDING_SHAPES = Maps.newEnumMap(ImmutableMap.of(class_2350.field_11043, class_2248.method_9541(5.5D, 3.0D, 11.0D, 10.5D, 13.0D, 16.0D), class_2350.field_11035, class_2248.method_9541(5.5D, 3.0D, 0.0D, 10.5D, 13.0D, 5.0D), class_2350.field_11039, class_2248.method_9541(11.0D, 3.0D, 5.5D, 16.0D, 13.0D, 10.5D), class_2350.field_11034, class_2248.method_9541(0.0D, 3.0D, 5.5D, 5.0D, 13.0D, 10.5D)));
    }
}

==> vplus-1.1.1-sources.jar: tech/nevets/vplus/blocks/ColorWallTorchBlock.java <==
package tech.nevets.vplus.blocks;

import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import net.minecraft.block.*;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1936;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2383;
import net.minecraft.class_2394;
import net.minecraft.class_2398;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_2527;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2753;
import net.minecraft.class_2769;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import org.jetbrains.annotations.Nullable;

import java.util.Map;
import java.util.Random;

public class ColorWallTorchBlock extends class_2527 {
    public static final class_2753 FACING;
    protected static final float field_31285 = 2.5F;
    private static final Map<class_2350, class_265> BOUNDING_SHAPES;

    protected ColorWallTorchBlock(class_2251 settings, class_2394 particleEffect) {
        super(settings, particleEffect);
        this.method_9590((class_2680)((class_2680)this.field_10647.method_11664()).method_11657(FACING, class_2350.field_11043));
    }

    public String method_9539() {
        return this.method_8389().method_7876();
    }

    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return getBoundingShape(state);
    }

    public static class_265 getBoundingShape(class_2680 state) {
        return (class_265)BOUNDING_SHAPES.get(state.method_11654(FACING));
    }

    public boolean method_9558(class_2680 state, class_4538 world, class_2338 pos) {
        class_2350 direction = (class_2350)state.method_11654(FACING);
        class_2338 blockPos = pos.method_10093(direction.method_10153());
        class_2680 blockState = world.method_8320(blockPos);
        return blockState.method_26206(world, blockPos, direction);
    }

    @Nullable
    public class_2680 method_9605(class_1750 ctx) {
        class_2680 blockState = this.method_9564();
        class_4538 worldView = ctx.method_8045();
        class_2338 blockPos = ctx.method_8037();
        class_2350[] directions = ctx.method_7718();
        class_2350[] var6 = directions;
        int var7 = directions.length;

        for(int var8 = 0; var8 < var7; ++var8) {
            class_2350 direction = var6[var8];
            if (direction.method_10166().method_10179()) {
                class_2350 direction2 = direction.method_10153();
                blockState = (class_2680)blockState.method_11657(FACING, direction2);
                if (blockState.method_26184(worldView, blockPos)) {
                    return blockState;
                }
            }
        }

        return null;
    }

    public class_2680 method_9559(class_2680 state, class_2350 direction, class_2680 neighborState, class_1936 world, class_2338 pos, class_2338 neighborPos) {
        return direction.method_10153() == state.method_11654(FACING) && !state.method_26184(world, pos) ? class_2246.field_10124.method_9564() : state;
    }

    public void method_9496(class_2680 state, class_1937 world, class_2338 pos, Random random) {
        class_2350 direction = (class_2350)state.method_11654(FACING);
        double d = (double)pos.method_10263() + 0.5D;
        double e = (double)pos.method_10264() + 0.7D;
        double f = (double)pos.method_10260() + 0.5D;
        double g = 0.22D;
        double h = 0.27D;
        class_2350 direction2 = direction.method_10153();
        world.method_8406(class_2398.field_11251, d + 0.27D * (double)direction2.method_10148(), e + 0.22D, f + 0.27D * (double)direction2.method_10165(), 0.0D, 0.0D, 0.0D);
        world.method_8406(this.field_22155, d + 0.27D * (double)direction2.method_10148(), e + 0.22D, f + 0.27D * (double)direction2.method_10165(), 0.0D, 0.0D, 0.0D);
    }

    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return (class_2680)state.method_11657(FACING, rotation.method_10503((class_2350)state.method_11654(FACING)));
    }

    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345((class_2350)state.method_11654(FACING)));
    }

    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(new class_2769[]{FACING});
    }

    static {
        FACING = class_2383.field_11177;
        BOUNDING_SHAPES = Maps.newEnumMap(ImmutableMap.of(class_2350.field_11043, class_2248.method_9541(5.5D, 3.0D, 11.0D, 10.5D, 13.0D, 16.0D), class_2350.field_11035, class_2248.method_9541(5.5D, 3.0D, 0.0D, 10.5D, 13.0D, 5.0D), class_2350.field_11039, class_2248.method_9541(11.0D, 3.0D, 5.5D, 16.0D, 13.0D, 10.5D), class_2350.field_11034, class_2248.method_9541(0.0D, 3.0D, 5.5D, 5.0D, 13.0D, 10.5D)));
    }
}
